MODULE trcini_mang
   !!======================================================================
   !!                         ***  MODULE trcini_mang  ***
   !! TOP :   initialisation of the manganese tracers
   !!======================================================================
   !! History :   0.0  !  2015-07  (M. van Hulten)  Based on Th/Pa code
   !!----------------------------------------------------------------------
   !! NEMO/TOP 3.6 , NEMO Consortium (2015)
   !! Software governed by the CeCILL licence     (NEMOGCM/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
#if defined key_mang
   !!----------------------------------------------------------------------
   !!   'key_mang'                                          Mn tracers
   !!----------------------------------------------------------------------
   !! trc_ini_mang   : Mn model initialisation
   !!----------------------------------------------------------------------
   USE oce_trc         ! Ocean variables
   USE par_trc         ! TOP parameters
   USE trc             ! TOP variables
   USE trcsms_mang     ! Mn sms trends

   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_ini_mang   ! called by trc_init() in trcini.F90

CONTAINS

   SUBROUTINE trc_ini_mang
      !!----------------------------------------------------------------------
      !!                     ***  trc_ini_mang  ***  
      !!
      !! ** Purpose :   initialization for Mn model
      !!
      !! ** Method  : - Read the namcfc namelist and check the parameter values
      !!----------------------------------------------------------------------

      !                       ! Allocate Mn arrays
      !IF( trc_sms_mang_alloc() /= 0 )   CALL ctl_stop( 'STOP', 'trc_ini_mang: unable to allocate Mn arrays' )
      ! TODO: if to be added, add allocate routine in trcsms_mang.F90 akin to trcsms_my_trc.F90

      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) ' trc_ini_mang: initialisation of Mn model'
      IF(lwp) WRITE(numout,*) ' ~~~~~~~~~~~~~~'
      
      IF( .NOT. ln_rsttr ) THEN
         IF(lwp) THEN
            WRITE(numout,*)
            WRITE(numout,*) 'No restart : Mn concentrations equal zero'
         ENDIF
         trn(:,:,:,jp_mang0:jp_mang1) = 0.
      ENDIF

   END SUBROUTINE trc_ini_mang

#else
   !!----------------------------------------------------------------------
   !!   Dummy module                                        No Mn model
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_ini_mang             ! Empty routine
   END SUBROUTINE trc_ini_mang
#endif

   !!======================================================================
END MODULE trcini_mang
